@@ -1,13 +1,13 @@
 var group__spa__pod =
 [
     [ "builder.h", "builder_8h.html", null ],
-    [ "command.h", "pod_2command_8h.html", null ],
+    [ "pod/command.h", "pod_2command_8h.html", null ],
     [ "compare.h", "compare_8h.html", null ],
-    [ "event.h", "pod_2event_8h.html", null ],
-    [ "filter.h", "spa_2include_2spa_2pod_2filter_8h.html", null ],
+    [ "pod/event.h", "pod_2event_8h.html", null ],
+    [ "spa/include/spa/pod/filter.h", "spa_2include_2spa_2pod_2filter_8h.html", null ],
     [ "iter.h", "iter_8h.html", null ],
     [ "parser.h", "parser_8h.html", null ],
-    [ "pod.h", "pod_2pod_8h.html", null ],
+    [ "pod/pod.h", "pod_2pod_8h.html", null ],
     [ "vararg.h", "vararg_8h.html", null ],
     [ "spa_pod_builder_state", "structspa__pod__builder__state.html", [
       [ "offset", "structspa__pod__builder__state.html#ac64c9a0aad0f5630c44c86e97561ffae", null ],
@@ -364,6 +364,7 @@ var group__spa__pod =
     [ "spa_pod_compare", "group__spa__pod.html#ga887a4f837a5690cc40fe30c8f4461452", null ],
     [ "spa_pod_choice_fix_default", "group__spa__pod.html#ga5e8d9e3e7fbbeff37cb0279160ca0962", null ],
     [ "spa_pod_filter_flags_value", "group__spa__pod.html#ga1a7880f8a28a30720da6bb6b636a9a1c", null ],
+    [ "spa_pod_filter_is_step_of", "group__spa__pod.html#ga37b7c8a0ca1e4adafd4670340328d125", null ],
     [ "spa_pod_filter_prop", "group__spa__pod.html#ga67f021221aaedced51ab95dd8e7ef895", null ],
     [ "spa_pod_filter_part", "group__spa__pod.html#ga5d676b81bf66a4147c0f52d8ebdd5b5c", null ],
     [ "spa_pod_filter", "group__spa__pod.html#gaf40f681348bff742f24935a2075ef3bb", null ],
