@@ -1,5 +1,24 @@
 var NAVTREEINDEX21 =
 {
+"structspa__fraction.html":[10,8,8,1,4],
+"structspa__fraction.html#a55246db96d647cd96be18983d59feb56":[10,8,8,1,4,0],
+"structspa__fraction.html#af099fb3a18c93ddac10239564da9de0c":[10,8,8,1,4,1],
+"structspa__graph.html":[10,8,5,3],
+"structspa__graph.html#a850c90822a1b32d7cd67ec5c76eda2fa":[10,8,5,3,0],
+"structspa__graph.html#a90439529765f13aadc6f1d7727244a1c":[10,8,5,3,3],
+"structspa__graph.html#a9bcd83554b53da4a139ed6a9be38bb1c":[10,8,5,3,1],
+"structspa__graph.html#aacd6dde80b95c6415d300f419ea6f144":[10,8,5,3,2],
+"structspa__graph__link.html":[10,8,5,2],
+"structspa__graph__link.html#a15313bfb8509b74448784ebf30f191c6":[10,8,5,2,1],
+"structspa__graph__link.html#ab1f910424f6a5ea5a34b52695536f53d":[10,8,5,2,0],
+"structspa__graph__link.html#ab7c807f9aaa9242cf8573b13212de674":[10,8,5,2,2],
+"structspa__graph__link.html#abf9a5059f5b888cf3a331832830f7373":[10,8,5,2,3],
+"structspa__graph__node.html":[10,8,5,5],
+"structspa__graph__node.html#a23c316f71a255a568e96092e72c40cae":[10,8,5,5,4],
+"structspa__graph__node.html#a6215edd0d426cfc8e697d648c09a4f57":[10,8,5,5,0],
+"structspa__graph__node.html#a6664b3c60baddc151a340bf2ebb3a5a2":[10,8,5,5,8],
+"structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740":[10,8,5,5,1],
+"structspa__graph__node.html#ab16592a35d02f827271786b49110341c":[10,8,5,5,7],
 "structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0":[10,8,5,5,6],
 "structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[10,8,5,5,3],
 "structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c":[10,8,5,5,5],
@@ -230,24 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__node__callbacks.html#a2e4fa7f89e8c1d306d44569191c44311":[10,8,6,24,1],
 "structspa__node__callbacks.html#a48ef28f7570e07dbfb45fdb247e02671":[10,8,6,24,2],
 "structspa__node__callbacks.html#a597eb6e41252d8030e4d697b51406ad0":[10,8,6,24,3],
-"structspa__node__events.html":[10,8,6,23],
-"structspa__node__events.html#a37b6ed18688f456b4c4e9b157879414f":[10,8,6,23,0],
-"structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741":[10,8,6,23,4],
-"structspa__node__events.html#a64cd08176057e03e97babf5b36ecd7bf":[10,8,6,23,3],
-"structspa__node__events.html#a6950a2df9f758cbbe7651f9db3962bed":[10,8,6,23,1],
-"structspa__node__events.html#a7915d7cc4ad14d41c0a0865798470429":[10,8,6,23,2],
-"structspa__node__info.html":[10,8,6,19],
-"structspa__node__info.html#a11fa9f260086bf624de400a80bf79219":[10,8,6,19,4],
-"structspa__node__info.html#a248c6cf0005c3b29a3ceb1bbff232cd9":[10,8,6,19,3],
-"structspa__node__info.html#a41964dbf3b7ace8dd61b9f82d123b4d6":[10,8,6,19,5],
-"structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5":[10,8,6,19,1],
-"structspa__node__info.html#a985458f3b046fb6b7da0974ac08fe504":[10,8,6,19,2],
-"structspa__node__info.html#a9f05f762157f2ae9db446937f19da173":[10,8,6,19,0],
-"structspa__node__methods.html":[10,8,6,25],
-"structspa__node__methods.html#a0ea59a508f6d40b5889c23940a036be6":[10,8,6,25,5],
-"structspa__node__methods.html#a1f465eba7a1322ef153142227a68d43b":[10,8,6,25,10],
-"structspa__node__methods.html#a2089aa56468969fa4e6e65d6c80dbd14":[10,8,6,25,13],
-"structspa__node__methods.html#a2216e9265fde3d179e7bec8ae69baecc":[10,8,6,25,15],
-"structspa__node__methods.html#a2773ceced2814d3adec184fa5ad538d2":[10,8,6,25,12],
-"structspa__node__methods.html#a2bb8310a8ab8273ac0f53b54c6b23223":[10,8,6,25,1]
+"structspa__node__events.html":[10,8,6,23]
 };
