@@ -8,9 +8,9 @@ var indexSectionsWithContent =
   5: "ps",
   6: "ps",
   7: "_ps",
-  8: "_ps",
+  8: "_eps",
   9: "abcdefghijklmnprstuw",
-  10: "acdlmopst"
+  10: "acdglmnopst"
 };
 
 var indexSectionNames =
